==> aws-cdk-scala-stepfunctions_2.12-0.1.7-sources.jar: io/burkard/cdk/services/stepfunctions/EksCall.scala <==
package io.burkard.cdk.services.stepfunctions

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object EksCall {

  def apply(
    internalResourceId: String,
    httpPath: String,
    httpMethod: software.amazon.awscdk.services.stepfunctions.tasks.HttpMethods,
    cluster: software.amazon.awscdk.services.eks.ICluster,
    resultPath: Option[String] = None,
    resultSelector: Option[Map[String, _]] = None,
    queryParameters: Option[Map[String, _ <: List[String]]] = None,
    heartbeat: Option[software.amazon.awscdk.Duration] = None,
    outputPath: Option[String] = None,
    comment: Option[String] = None,
    requestBody: Option[software.amazon.awscdk.services.stepfunctions.TaskInput] = None,
    integrationPattern: Option[software.amazon.awscdk.services.stepfunctions.IntegrationPattern] = None,
    inputPath: Option[String] = None,
    timeout: Option[software.amazon.awscdk.Duration] = None
  )(implicit stackCtx: software.amazon.awscdk.Stack): software.amazon.awscdk.services.stepfunctions.tasks.EksCall =
    software.amazon.awscdk.services.stepfunctions.tasks.EksCall.Builder
      .create(stackCtx, internalResourceId)
      .httpPath(httpPath)
      .httpMethod(httpMethod)
      .cluster(cluster)
      .resultPath(resultPath.orNull)
      .resultSelector(resultSelector.map(_.asJava).orNull)
      .queryParameters(queryParameters.map(_.mapValues(_.asJava).toMap.asJava).orNull)
      .heartbeat(heartbeat.orNull)
      .outputPath(outputPath.orNull)
      .comment(comment.orNull)
      .requestBody(requestBody.orNull)
      .integrationPattern(integrationPattern.orNull)
      .inputPath(inputPath.orNull)
      .timeout(timeout.orNull)
      .build()
}

==> aws-cdk-scala-stepfunctions_2.13-0.4.1-sources.jar: io/burkard/cdk/services/stepfunctions/EksCall.scala <==
package io.burkard.cdk.services.stepfunctions

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object EksCall {

  def apply(
    internalResourceId: String,
    httpPath: String,
    httpMethod: software.amazon.awscdk.services.stepfunctions.tasks.HttpMethods,
    cluster: software.amazon.awscdk.services.eks.ICluster,
    resultPath: Option[String] = None,
    requestBody: Option[software.amazon.awscdk.services.stepfunctions.TaskInput] = None,
    integrationPattern: Option[software.amazon.awscdk.services.stepfunctions.IntegrationPattern] = None,
    outputPath: Option[String] = None,
    comment: Option[String] = None,
    resultSelector: Option[Map[String, _]] = None,
    queryParameters: Option[Map[String, _ <: List[String]]] = None,
    inputPath: Option[String] = None,
    timeout: Option[software.amazon.awscdk.Duration] = None,
    heartbeat: Option[software.amazon.awscdk.Duration] = None
  )(implicit stackCtx: software.amazon.awscdk.Stack): software.amazon.awscdk.services.stepfunctions.tasks.EksCall =
    software.amazon.awscdk.services.stepfunctions.tasks.EksCall.Builder
      .create(stackCtx, internalResourceId)
      .httpPath(httpPath)
      .httpMethod(httpMethod)
      .cluster(cluster)
      .resultPath(resultPath.orNull)
      .requestBody(requestBody.orNull)
      .integrationPattern(integrationPattern.orNull)
      .outputPath(outputPath.orNull)
      .comment(comment.orNull)
      .resultSelector(resultSelector.map(_.asJava).orNull)
      .queryParameters(queryParameters.map(_.mapValues(_.asJava).toMap.asJava).orNull)
      .inputPath(inputPath.orNull)
      .timeout(timeout.orNull)
      .heartbeat(heartbeat.orNull)
      .build()
}
